.. _spkg_pyppeteer:

pyppeteer: Headless chrome/chromium automation library
================================================================

Description
-----------

Headless chrome/chromium automation library (unofficial port of puppeteer)

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/pyppeteer/


Type
----

optional


Dependencies
------------

- $(PYTHON)
- $(PYTHON_TOOLCHAIN)
- :ref:`spkg_appdirs`
- :ref:`spkg_certifi`
- :ref:`spkg_importlib_metadata`
- :ref:`spkg_urllib3`

Version Information
-------------------

requirements.txt::

    pyppeteer


Equivalent System Packages
--------------------------

.. tab:: conda-forge

   .. CODE-BLOCK:: bash

       $ conda install pyppeteer 



If the system package is installed and if the (experimental) option
``--enable-system-site-packages`` is passed to ``./configure``, then ``./configure``
will check if the system package can be used.

